@@ -129,7 +129,7 @@ where
     F: Fn(&mut W, &mut Context, Routed<Response>) -> bool,
 {
     f: F,
-    _w: std::marker::PhantomData<W>,
+    _w: core::marker::PhantomData<W>,
 }
 
 impl<W, F> ResponseParser<W, F>
@@ -148,7 +148,7 @@ where
     pub fn new(f: F) -> Self {
         Self {
             f,
-            _w: std::marker::PhantomData,
+            _w: core::marker::PhantomData,
         }
     }
 }
